powered by
Creates a list of default attribute lists for each panel type.
labels_att(show = FALSE)
A list of defaults to be stored in the overall attribute list.
If show equals FALSE, then the resulting list is returned invisibly.
Quinn Payton Payton.Quinn@epa.gov