labels_build: Builds panels
Description
Creates a panel of the user specified type using the attribute list to make
adjustments.
Usage
labels_build(pl, p, DF, att)
Value
Returns a ggplot object to be printed later in the lmplot function.
Arguments
- pl
the lmplot object being constructed.
- p
number of the panel within the plot.
- DF
the data table of statistics to be referenced.
- att
the attribute list to specify visual and graphical
characteristics.