Learn R Programming

micromap (version 1.9.12)

print.mm: Print lmplot Object to a File

Description

Takes a stored lmplot object of class mm and prints to a file whose type is implied by the file name.

Usage

# S3 method for mm
print(x, name = NULL, res = 300, ...)

Value

Returns nothing.

Arguments

x

name of the lmplot object.

name

name of the file to be produced. tiff, png, jpeg, and pdf are recognized.

res

resolution in dpi.

...

Additional arguments. (Currently ignored.)

Author

Quinn Payton Payton.Quinn@epa.gov