Learn R Programming

micromap (version 1.9.11)

labels_att: Default Attribute Lists

Description

Creates a list of default attribute lists for each panel type.

Usage

labels_att(show = FALSE)

Value

A list of defaults to be stored in the overall attribute list.

Arguments

show

If show equals FALSE, then the resulting list is returned invisibly.

Author

Quinn Payton Payton.Quinn@epa.gov