powered by
Creates a list of default attribute lists for each panel type.
labels_att(show=FALSE)
If show equals FALSE, then the resulting list is returned invisibly.
A list of defaults to be stored in the overall attribute list.