Rdocumentation
powered by
Learn R Programming
micromap (version 1.9.2)
vegCov: Example Dataset: Vegetation Coverage Percentages
Description
A subset of a larger vegetation coverage analysis dataset.
Usage
data(vegCov)
Arguments
Format
A data frame with 12 rows and the following 13 columns:
Type
the population name.
Subpopulation
the subpopulation name, either national or level 3 ecoregion.
Indicator
the ecological variable (indicator)
Category
category of disturbance.
NResp
sample size.
Estimate.P
estimated percentage of vegetation coverage with a given classification.
StdError.P
standard error of the percentage estimate.
LCB95Pct.P
lower bound of a 95 percent confidence interval for the estimated percentage.
UCB95Pct.P
upper bound of a 95 percent confidence interval for the estimated percentage.
Estimate.U
estimated area of vegetation coverage with a given classification.
StdError.U
standard error of the area estimate.
LCB95Pct.U
lower bound of a 95 percent confidence interval for the estimated area.
UCB95Pct.U
upper bound of a 95 percent confidence interval for the estimated area.
Examples
Run this code
data(vegCov)
head(vegCov)
Run the code above in your browser using
DataLab